import{d as i,o as p,c as n,w as m,b as a,u as t}from"./index.5aecb583.js";import"./linters.fe07d562.js";import{W as s}from"./workspaces.bf51056b.js";import{C as d}from"./ContentLayout.f36ab983.js";import{_ as f,E as c}from"./View.vue_vue_type_script_setup_true_lang.529ad220.js";import"./asyncComputed.919e81fb.js";import"./workspaceStore.d4664f94.js";import"./url.d1aedda8.js";import"./colorHelpers.25ec075c.js";import"./record.7b9a0c18.js";import"./gateway.a0446a31.js";import"./popupNotifcation.a70532ef.js";import"./fetch.5d4b3827.js";import"./SaveButton.ad706c5b.js";import"./UnsavedChangesHandler.a33b5aee.js";import"./ExclamationCircleOutlined.f3294aae.js";import"./CrudView.73b246a5.js";import"./router.187239be.js";import"./Badge.1d490ce7.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.1a4649a6.js";import"./BookOutlined.1b5c2f81.js";import"./PhDotsThreeVertical.vue.db9739bb.js";import"./index.71e3aaff.js";import"./index.07e90e85.js";import"./polling.82e59f77.js";import"./PhPencil.vue.03a4e6ee.js";import"./index.1ef256d6.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="ab65be80-359c-4857-940a-7750839331bd",o._sentryDebugIdIdentifier="sentry-dbid-ab65be80-359c-4857-940a-7750839331bd")}catch{}})();const G=i({__name:"EnvVarsEditor",setup(o){const r=new c;return(e,u)=>(p(),n(d,null,{default:m(()=>[a(f,{"env-var-repository":t(r),mode:"editor","file-opener":t(s)},null,8,["env-var-repository","file-opener"])]),_:1}))}});export{G as default};
//# sourceMappingURL=EnvVarsEditor.4fcd34fa.js.map
