import{_ as n,C as p}from"./View.vue_vue_type_script_setup_true_lang.529ad220.js";import{d as i,ea as s,o as a,c,u as m}from"./index.5aecb583.js";import"./gateway.a0446a31.js";import"./popupNotifcation.a70532ef.js";import"./fetch.5d4b3827.js";import"./record.7b9a0c18.js";import"./SaveButton.ad706c5b.js";import"./UnsavedChangesHandler.a33b5aee.js";import"./ExclamationCircleOutlined.f3294aae.js";import"./CrudView.73b246a5.js";import"./router.187239be.js";import"./Badge.1d490ce7.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.1a4649a6.js";import"./BookOutlined.1b5c2f81.js";import"./url.d1aedda8.js";import"./PhDotsThreeVertical.vue.db9739bb.js";import"./index.71e3aaff.js";import"./index.07e90e85.js";import"./asyncComputed.919e81fb.js";import"./polling.82e59f77.js";import"./PhPencil.vue.03a4e6ee.js";import"./index.1ef256d6.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="d54bbc49-421b-4ccc-9add-18695bef8c8a",o._sentryDebugIdIdentifier="sentry-dbid-d54bbc49-421b-4ccc-9add-18695bef8c8a")}catch{}})();const A=i({__name:"EnvVars",setup(o){const t=s().params.projectId,e=new p(t);return(d,f)=>(a(),c(n,{"env-var-repository":m(e),mode:"console"},null,8,["env-var-repository"]))}});export{A as default};
//# sourceMappingURL=EnvVars.bb06e99f.js.map
