import{C as n}from"./gateway.a0446a31.js";import"./index.5aecb583.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="c7f693e8-17b7-4f52-a2ee-2ce8e84cf9df",t._sentryDebugIdIdentifier="sentry-dbid-c7f693e8-17b7-4f52-a2ee-2ce8e84cf9df")}catch{}})();class i{async create(e){return n.post(`organizations/${e.organizationId}/members`,{email:e.email,teams:e.teams})}async delete(e){return n.delete(`organizations/${e.organizationId}/members/${e.authorId}`)}async list(e){return n.get(`organizations/${e}/members`)}async get(e,r){return n.get(`organizations/${e}/members/${r}`)}async update(e,r,a){return n.patch(`organizations/${e}/members/${r}`,a)}}export{i as M};
//# sourceMappingURL=member.90101591.js.map
