import{_ as n}from"./TasksView.vue_vue_type_script_setup_true_lang.278e68a3.js";import{L as i}from"./tasksController.659c345f.js";import{d,o as p,c,w as o,b as s,aG as f,u as a,dd as _,a0 as m}from"./index.5aecb583.js";import{C as l}from"./ContentLayout.f36ab983.js";import"./metadata.21f60d9a.js";import"./PhWebhooksLogo.vue.038ad7fc.js";import"./ant-design.062152ca.js";import"./string.29356842.js";import"./dayjs.6ca42570.js";import"./index.71e3aaff.js";import"./gateway.a0446a31.js";import"./popupNotifcation.a70532ef.js";import"./polling.82e59f77.js";import"./scripts.ade32b25.js";import"./record.7b9a0c18.js";import"./linters.fe07d562.js";import"./asyncComputed.919e81fb.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="f04e9149-3558-43b9-8f15-d3caffd1db48",t._sentryDebugIdIdentifier="sentry-dbid-f04e9149-3558-43b9-8f15-d3caffd1db48")}catch{}})();const u=d({__name:"Tasks",setup(t){const e=new i;return(r,y)=>(p(),c(l,null,{default:o(()=>[s(a(_),null,{default:o(()=>[f("Tasks")]),_:1}),s(n,{class:"tasks",api:a(e),stages:null,editor:""},null,8,["api"])]),_:1}))}});const G=m(u,[["__scopeId","data-v-10aa4cc9"]]);export{G as default};
//# sourceMappingURL=Tasks.56e4a16a.js.map
