import{k as a,T as n,m as r,P as o,C as c,M as d,s as p,n as s,p as b,q as f,t as m,v as u}from"./index.5aecb583.js";import{s as g,c as y,a as i}from"./workspaceStore.d4664f94.js";import{_ as l}from"./App.vue_vue_type_style_index_0_lang.c92df07b.js";import"./url.d1aedda8.js";import"./colorHelpers.25ec075c.js";import"./PlayerConfigProvider.b292d894.js";import"./index.c4ea5de6.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="9b8cef2b-e785-4804-8fba-7bacc57ebb9d",t._sentryDebugIdIdentifier="sentry-dbid-9b8cef2b-e785-4804-8fba-7bacc57ebb9d")}catch{}})();class w{static init(){setInterval(()=>fetch("/_version"),20*1e3)}}(async()=>{await g();const t=y(),e=a({render:()=>b(l)});n.init(),r(e,i),w.init(),e.use(i),e.use(t),e.use(o),e.mount("#app"),e.component("VSelect",c),e.component("Markdown",d),e.component("Message",p),s(e,f),s(e,m),s(e,u)})();
//# sourceMappingURL=player.80963c7c.js.map
