import{d as a,o as n,Y as s,a as d,$ as r,ed as l,a0 as _}from"./index.5aecb583.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="bd0417ed-aca9-4b76-8969-19ab259fa685",e._sentryDebugIdIdentifier="sentry-dbid-bd0417ed-aca9-4b76-8969-19ab259fa685")}catch{}})();const c={class:"content-layout"},u=a({__name:"ContentLayout",props:{fullWidth:{type:Boolean}},setup(e){return(t,o)=>(n(),s("div",c,[d("div",{class:l(["centered-layout",{"full-width":t.fullWidth}])},[r(t.$slots,"default",{},void 0,!0)],2)]))}});const f=_(u,[["__scopeId","data-v-6397d501"]]);export{f as C};
//# sourceMappingURL=ContentLayout.f36ab983.js.map
