import{d as o,o as a,Y as s,b as d,u as r,by as _,a0 as c}from"./index.5aecb583.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="4e6b6637-ae84-4299-84fe-153d90c57c14",e._sentryDebugIdIdentifier="sentry-dbid-4e6b6637-ae84-4299-84fe-153d90c57c14")}catch{}})();const i={class:"centered"},f=o({__name:"LoadingContainer",setup(e){return(n,t)=>(a(),s("div",i,[d(r(_))]))}});const u=c(f,[["__scopeId","data-v-52e6209a"]]);export{u as L};
//# sourceMappingURL=LoadingContainer.685136d3.js.map
