import{O as r}from"./workspaceStore.d4664f94.js";import{d as i,X as l,o as c,Y as u,b as n,w as a,u as d,aG as o,dd as f,dc as b}from"./index.5aecb583.js";import"./url.d1aedda8.js";import"./colorHelpers.25ec075c.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="7198dc12-83d3-403d-937b-c520e74b17e7",e._sentryDebugIdIdentifier="sentry-dbid-7198dc12-83d3-403d-937b-c520e74b17e7")}catch{}})();const w=i({__name:"OidcLoginCallback",setup(e){return l(async()=>{await new r().loginCallback()}),(t,s)=>(c(),u("div",null,[n(d(f),null,{default:a(()=>[o("You're authenticated")]),_:1}),n(d(b),null,{default:a(()=>[o(" This window should close automatically. Please close it manually if it doesn't. ")]),_:1})]))}});export{w as default};
//# sourceMappingURL=OidcLoginCallback.4ff1d215.js.map
