import{P as f}from"./PlayerNavbar.3154d243.js";import{d as g,eo as h,ea as c,e as y,f as b,r as k,o as i,Y as v,u as a,c as w,S as L,a as C,b as I,a0 as N}from"./index.5aecb583.js";import{u as V}from"./workspaceStore.d4664f94.js";import"./metadata.21f60d9a.js";import"./PhWebhooksLogo.vue.038ad7fc.js";import"./LoadingOutlined.ff0e335a.js";import"./PhSignOut.vue.326953b2.js";import"./index.9e74a977.js";import"./Avatar.dc15e97c.js";import"./url.d1aedda8.js";import"./colorHelpers.25ec075c.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="878c861e-c39c-4ae9-9918-f42111250b83",o._sentryDebugIdIdentifier="sentry-dbid-878c861e-c39c-4ae9-9918-f42111250b83")}catch{}})();const x={class:"main-container"},B={class:"content"},D=g({__name:"Main",setup(o){const e=h(),t=V(),u=c().path,n=y(null),d=async({path:s,id:r})=>{n.value=r,await e.push({path:`/${s}`}),n.value=null},l=()=>{e.push({name:"playerLogin"})},p=()=>{e.push({name:"playerLogin"})},_=b(()=>!!c().meta.hideLogin);return(s,r)=>{const m=k("RouterView");return i(),v("div",x,[a(t).state.workspace?(i(),w(f,{key:0,"current-path":a(u),"hide-login":_.value,"runner-data":a(t).state.workspace,loading:n.value,onNavigate:d,onLoginClick:p,onLogoutClick:l},null,8,["current-path","hide-login","runner-data","loading"])):L("",!0),C("section",B,[I(m)])])}}});const A=N(D,[["__scopeId","data-v-f095bece"]]);export{A as default};
//# sourceMappingURL=Main.aff3827c.js.map
