import{_ as m}from"./TasksView.vue_vue_type_script_setup_true_lang.278e68a3.js";import{R as f}from"./tasksController.659c345f.js";import{d as _,ea as y,f as g,o as n,Y as b,b as w,w as k,u as l,c as I,S as T,aS as v,aG as B,dd as S}from"./index.5aecb583.js";import"./gateway.a0446a31.js";import{a as j,B as x}from"./build.13196e3d.js";import{a as C}from"./project.5a31b224.js";import"./tables.c30238b1.js";import{a as D}from"./asyncComputed.919e81fb.js";import"./metadata.21f60d9a.js";import"./PhWebhooksLogo.vue.038ad7fc.js";import"./ant-design.062152ca.js";import"./string.29356842.js";import"./dayjs.6ca42570.js";import"./index.71e3aaff.js";import"./polling.82e59f77.js";import"./scripts.ade32b25.js";import"./record.7b9a0c18.js";import"./linters.fe07d562.js";import"./popupNotifcation.a70532ef.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="854fe366-dfa6-408c-8c36-9287f07970af",e._sentryDebugIdIdentifier="sentry-dbid-854fe366-dfa6-408c-8c36-9287f07970af")}catch{}})();const Q=_({__name:"Tasks",setup(e){const a=y().params.projectId,p=new f(a),{result:o}=D(async()=>{const r=(await j.list(a)).find(d=>d.latest);if(!r)return null;const[u,c]=await Promise.all([x.get(r.id),C.get(a)]);return{buildSpec:u,project:c}}),i=g(()=>!o.value||!o.value.buildSpec?null:o.value.buildSpec.runtimes.map(t=>({id:t.id,stageTitle:t.title,stageType:t.type})));return(t,r)=>(n(),b(v,null,[w(l(S),null,{default:k(()=>[B("Tasks")]),_:1}),i.value?(n(),I(m,{key:0,class:"tasks",api:l(p),stages:i.value},null,8,["api","stages"])):T("",!0)],64))}});export{Q as default};
//# sourceMappingURL=Tasks.d75d970c.js.map
