import{U as s,dA as i,dB as d}from"./index.5aecb583.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="493f0b5e-c287-4c0c-a293-def557cc30a4",e._sentryDebugIdIdentifier="sentry-dbid-493f0b5e-c287-4c0c-a293-def557cc30a4")}catch{}})();const{DatePicker:n,WeekPicker:t,MonthPicker:c,YearPicker:f,TimePicker:m,QuarterPicker:r,RangePicker:a}=i(d),y=s(n,{WeekPicker:t,MonthPicker:c,YearPicker:f,RangePicker:a,TimePicker:m,QuarterPicker:r,install:e=>(e.component(n.name,n),e.component(a.name,a),e.component(c.name,c),e.component(t.name,t),e.component(r.name,r),e)});export{y as D,c as M,r as Q,a as R,t as W};
//# sourceMappingURL=dayjs.6ca42570.js.map
