import{_ as f}from"./Login.vue_vue_type_script_setup_true_lang.2d0dfb21.js";import{d as l,eo as m,ea as b,o as g,Y as y,b as w,u as n,a0 as k}from"./index.5aecb583.js";import{u as h}from"./workspaceStore.d4664f94.js";import"./Logo.d4f441cc.js";import"./string.29356842.js";import"./CircularLoading.b5a5e4dd.js";import"./index.c4ea5de6.js";import"./index.1ef256d6.js";import"./url.d1aedda8.js";import"./colorHelpers.25ec075c.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="3afc6d5b-2c12-43f9-a88a-0ea830bf2b32",e._sentryDebugIdIdentifier="sentry-dbid-3afc6d5b-2c12-43f9-a88a-0ea830bf2b32")}catch{}})();const v={class:"runner"},I=l({__name:"Login",setup(e){const o=m(),a=b(),t=h(),_=async()=>{const{redirect:r,...s}=a.query;if(r){await o.push({path:r,query:s,params:a.params});return}o.push({name:"playerHome",query:s})};return(r,s)=>{var c,d,p,u,i;return g(),y("div",v,[w(f,{"logo-url":(d=(c=n(t).state.workspace)==null?void 0:c.logoUrl)!=null?d:void 0,"brand-name":(p=n(t).state.workspace)==null?void 0:p.brandName,locale:(i=(u=n(t).state.workspace)==null?void 0:u.language)!=null?i:"en",onDone:_},null,8,["logo-url","brand-name","locale"])])}}});const H=k(I,[["__scopeId","data-v-ce854d6f"]]);export{H as default};
//# sourceMappingURL=Login.f7b7d5cb.js.map
