import{d as l,eh as c,f as r,o,Y as t,S as d,e9 as _,a0 as f}from"./index.5aecb583.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="52c78f1b-6227-4b61-a51d-7a637f1af938",e._sentryDebugIdIdentifier="sentry-dbid-52c78f1b-6227-4b61-a51d-7a637f1af938")}catch{}})();const p={class:"logo"},u=["src","alt"],g={key:1},m=l({__name:"Logo",props:{imageUrl:{},brandName:{},hideText:{type:Boolean},size:{}},setup(e){const a=e;c(s=>({"9303a762":n.value}));const n=r(()=>a.size==="small"?"24px":a.size==="large"?"80px":"50px"),i=r(()=>`${a.brandName} Logo`);return(s,y)=>(o(),t("div",p,[s.imageUrl?(o(),t("img",{key:0,class:"logo-img",src:s.imageUrl,alt:i.value},null,8,u)):d("",!0),s.hideText?d("",!0):(o(),t("span",g,_(s.brandName),1))]))}});const h=f(m,[["__scopeId","data-v-f2a3ae27"]]);export{h as L};
//# sourceMappingURL=Logo.d4f441cc.js.map
